@@ -6,9 +6,10 @@
 
 #include "kirigamiplasmafactory.h"
 #include "plasmadesktoptheme.h"
+#include "units.h"
 
 KirigamiPlasmaFactory::KirigamiPlasmaFactory(QObject *parent)
-    : Kirigami::KirigamiPluginFactory(parent)
+    : Kirigami::KirigamiPluginFactoryV2(parent)
 {
 }
 
@@ -20,4 +21,10 @@ Kirigami::PlatformTheme *KirigamiPlasmaFactory::createPlatformTheme(QObject *par
     return new PlasmaDesktopTheme(parent);
 }
 
+Kirigami::Units *KirigamiPlasmaFactory::createUnits(QObject *parent)
+{
+    Q_ASSERT(parent);
+    return new Units(parent);
+}
+
 #include "moc_kirigamiplasmafactory.cpp"
